"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const utils_1 = require("@morjs/utils");
const path_1 = tslib_1.__importDefault(require("path"));
const templateTransformer_1 = require("../transformers/templateTransformer");
async function TemplateLoader(fileContent) {
    const cb = this.async();
    const { userConfig, entryBuilder, runner, singleTags, closingSingleTag } = this.getOptions();
    const entry = entryBuilder.getEntryByFilePath(this.resourcePath);
    const pluginInfo = {
        userConfig,
        loaderContext: this,
        fileInfo: {
            path: this.resourcePath,
            content: fileContent,
            extname: entry ? entry.extname : path_1.default.extname(this.resourcePath),
            entryName: entry ? entry.fullEntryName : undefined,
            entryFileType: entry ? entry.entryFileType : undefined,
            entryType: entry ? entry.entryType : utils_1.EntryType.unknown
        }
    };
    // template 插件支持
    let parser;
    if (runner.hooks.templateParser.isUsed()) {
        parser = (tree) => runner.hooks.templateParser.promise(tree, pluginInfo);
    }
    try {
        fileContent = await (0, templateTransformer_1.templateTransformer)(fileContent, pluginInfo, singleTags, closingSingleTag, parser);
    }
    catch (error) {
        return cb(error);
    }
    cb(null, fileContent);
}
exports.default = TemplateLoader;
//# sourceMappingURL=templateLoader.js.map